@@ -291,7 +291,11 @@ $VAR1 = {
         'translate'         => 'Übersetzen',
         'news'              => 'Blog',
         'mediumblob' =>
-          '0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]'
+          '0-16,777,215 bytes Attributes: Global Only(case sensitive) Default: NULL ["" if NOT NULL]',
+        'sendpassword'   => 'Passwort versendet.',
+	'lostpass'       => 'Dein Passwort',
+	'lostpassmessage'=> 'Du erhälst diese Mail weil Du dein Passwort angefordert hast.',
+	'forgetPass'     => 'Passwort vergessen.',
     },
     'en' => {
         'createdatabase'     => 'New Database',
@@ -587,7 +591,11 @@ $VAR1 = {
         'explorer'       => 'Explorer',
         'edittableprops' => 'Table',
         'servername'     => 'servername',
-        'sub_part'       => 'sub_part'
+        'sub_part'       => 'sub_part',
+        'sendpassword'   => 'Password put out.',
+	'lostpass'       => 'Your Password',
+	'lostpassmessage'=> 'You lost your Password, here it is.',
+	'forgetPass'     => 'Foget Password.',
     }
 };
 $lang = $VAR1;
