@@ -33,7 +33,7 @@ $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
         qw(quote quote_identifier CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
 );
-$DBI::Library::VERSION = '0.98';
+$DBI::Library::VERSION = '0.99';
 $m_tbl                 = 'querys';
 $driver                = 'mysql';
 require Exporter;
@@ -41,12 +41,14 @@ use DBI;
 
 use base qw/Exporter DBI/;
 
-# use Exporter qw/import/;
-
 =head1 NAME
 
 DBI::Library - DBI subclass providing a dynamic SQL Libary.
 
+=head1 VERSION
+
+This documentation refers to <DBI::Library> version 0.99
+
 =head1 SYNOPSIS
 
 FO Syntax
@@ -317,18 +319,17 @@ Fo Syntax:
 sub addexecute {
     my ($self, @p) = getSelf(@_);
     my $hash        = $p[0];
-    my $m_sTitle    = ((defined $hash->{title})) ? $hash->{title} : 0;
-    my $sql         = $hash->{sql} if ((defined $hash->{sql}));
-    my $description = $hash->{description} if (defined $hash->{description});
-    my $return      = $hash->{'return'} if (defined $hash->{'return'});
-    unless ($m_hFunctions{$m_sTitle}) {
-        my $sql_addexecute =
-          qq/INSERT INTO querys(`title`,`sql`,`description`,`return`) VALUES(?,?,?,?);/;
+    my $title    = defined $hash->{title} ? $hash->{title} : 0;
+    my $sql         = defined $hash->{sql} ? $hash->{sql} : 0;
+    my $description = defined $hash->{description} ? $hash->{description}:0;
+    my $return      = defined $hash->{'return'} ? $hash->{'return'} :0;
+    unless ($m_hFunctions{$title}  and $title and $sql and $description and $return) {
+        my $sql_addexecute = qq/INSERT INTO querys(`title`,`sql`,`description`,`return`) VALUES(?,?,?,?);/;
         my $sth = $m_dbh->prepare($sql_addexecute);
-        $sth->execute($m_sTitle, $sql, $description, $return)
-          or warn $m_dbh->errstr;
+        $sth->execute($title, $sql, $description, $return) or warn $m_dbh->errstr;
         $sth->finish();
         $self->updateModules();
+        return 1;
     } else {
         return 0;
     }
@@ -357,21 +358,20 @@ sub addexecute {
 sub editexecute {
     my ($self, @p) = getSelf(@_);
     my $hash = $p[0];
-    my $m_sTitle = ((defined $hash->{title})) ? $hash->{title} : 0;
-    my $newTitle =
-      ((defined $hash->{newTitle})) ? $hash->{newTitle} : $m_sTitle;
-    my $sql         = $hash->{sql}         if ((defined $hash->{sql}));
-    my $description = $hash->{description} if (defined $hash->{description});
-    my $return = (defined $hash->{'return'}) ? $hash->{'return'} : 'array';
+    my $title = defined $hash->{title} ? $hash->{title} : 0;
+    my $newTitle = defined $hash->{newTitle} ? $hash->{newTitle} : $title;
+    my $sql         = defined $hash->{sql} ? $hash->{sql} : 0;
+    my $description = defined $hash->{description} ? $hash->{description} :0;
+    my $return = defined $hash->{'return'} ? $hash->{'return'} : 'array';
 
-    if ($m_hFunctions{$m_sTitle}) {
+    if ($m_hFunctions{$title} and $title and $newTitle and $sql and $description ) {
         my $sql_edit =
           qq(update querys set title = ?, sql=? ,description=?,return=? where title = ? );
         my $sth = $m_dbh->prepare($sql_edit);
-        $sth->execute($newTitle, $sql, $description, $return, $m_sTitle)
+        $sth->execute($newTitle, $sql, $description, $return, $title)
           or warn $m_dbh->errstr;
         $sth->finish();
-
+	return 1;
     } else {
         return 0;
     }
@@ -379,7 +379,7 @@ sub editexecute {
 
 =head2 useexecute()
 
-        useexecute($m_sTitle,optional hashref {identifier => {1 => 'news', 2 => 'querys'}  , @parameter);
+        useexecute($title,optional hashref {identifier => {1 => 'news', 2 => 'querys'}  , @parameter);
 
 example:
 
@@ -403,10 +403,10 @@ example:
 
 sub useexecute {
     my ($self, @p) = getSelf(@_);
-    my $m_sTitle = shift(@p);
+    my $title = shift(@p);
     my $sql      = 'select `sql`,`return` from querys where `title` = ?';
     my $sth      = $m_dbh->prepare($sql);
-    $sth->execute($m_sTitle) or warn $m_dbh->errstr;
+    $sth->execute($title) or warn $m_dbh->errstr;
     my ($sqlexec, $return) = $sth->fetchrow_array();
     $sqlexec =~ s/<TABLE>/$m_tbl/g;
     if (ref $p[0] eq 'HASH') {
@@ -416,7 +416,7 @@ sub useexecute {
         }
     }
     $sth->finish();
-    return eval(" \$self->$return(\$sqlexec,\@p)");
+    return eval{$self->$return($sqlexec,@p)};
 }
 
 =head2 deleteexecute()
@@ -444,17 +444,18 @@ sub fetch_array {
     my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my @r;
-    eval('
-my $sth = $m_dbh->prepare($sql);
-if(defined $p[0]) {
-$sth->execute(@p) or warn $m_dbh->errstr;
-}else {
-$sth->execute() or warn $m_dbh->errstr;
-}
-while(my @comms = $sth->fetchrow_array()) {
-push(@r, @comms);
-}
-$sth->finish();');
+    eval{
+      my $sth = $m_dbh->prepare($sql);
+      if(defined $p[0]) {
+      $sth->execute(@p) or warn $m_dbh->errstr;
+      }else {
+      $sth->execute() or warn $m_dbh->errstr;
+      }
+      while(my @comms = $sth->fetchrow_array()) {
+      push(@r, @comms);
+      }
+      $sth->finish();
+    };
     @r = $@ if $@;
     return @r;
 }
@@ -469,17 +470,18 @@ sub fetch_AoH {
     my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my @r;
-    eval('
-my $sth = $m_dbh->prepare($sql);
-if(defined $p[0]) {
-$sth->execute(@p) or warn $m_dbh->errstr;
-} else {
-$sth->execute() or warn $m_dbh->errstr;
-}
-while(my $h = $sth->fetchrow_hashref) {
-push(@r, $h);
-}
-$sth->finish();');
+    eval{
+      my $sth = $m_dbh->prepare($sql);
+      if(defined $p[0]) {
+      $sth->execute(@p) or warn $m_dbh->errstr;
+      } else {
+      $sth->execute() or warn $m_dbh->errstr;
+      }
+      while(my $h = $sth->fetchrow_hashref) {
+      push(@r, $h);
+      }
+      $sth->finish();
+    };
     @r = $@ if $@;
     return @r;
 }
@@ -494,16 +496,16 @@ sub fetch_hashref {
     my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my $h;
-    eval('
-my $sth = $m_dbh->prepare($sql);
-if(defined $p[0]) {
-$sth->execute(@p) or warn $m_dbh->errstr;
-} else {
-$sth->execute() or warn $m_dbh->errstr;
-}
-$h = $sth->fetchrow_hashref();
-$sth->finish();
-');
+    eval{
+      my $sth = $m_dbh->prepare($sql);
+      if(defined $p[0]) {
+      $sth->execute(@p) or warn $m_dbh->errstr;
+      } else {
+      $sth->execute() or warn $m_dbh->errstr;
+      }
+      $h = $sth->fetchrow_hashref();
+      $sth->finish();
+    };
     $h = "$@" if $@;
     return $h;
 }
@@ -518,12 +520,13 @@ sub void {
     my ($self, @p) = getSelf(@_);
     my $sql = shift @p;
     my $sth = $m_dbh->prepare($sql);
-    eval('
-if(defined $p[0]) {
-$sth->execute(@p) or warn $m_dbh->errstr;
-} else {
-$sth->execute() or warn $m_dbh->errstr;
-}');
+    eval{
+      if(defined $p[0]) {
+	$sth->execute(@p) or warn $m_dbh->errstr;
+      } else {
+	$sth->execute() or warn $m_dbh->errstr;
+      }
+    };
     $sth->finish();
     return "$@" if $@;
 }
@@ -644,7 +647,7 @@ use vars qw(@ISA);
 sub execute {
     my ($sth, @args) = @_;
     my $rv;
-    eval('$rv = $sth->SUPER::execute(@args)');
+    eval{$rv = $sth->SUPER::execute(@args)};
     return "$@" if $@;
     return $rv;
 }
@@ -658,10 +661,13 @@ sub fetch {
     my ($sth, @args) = @_;
 
     my $row;
-    eval('$row = $sth->SUPER::fetch(@args)');
+    eval{$row = $sth->SUPER::fetch(@args)};
     return "$@" if $@;
     if ($row) {
-        utf8::encode($row->[1]) if (utf8::is_utf8($row->[1]));
+	eval{
+	  use Search::Tools::UTF8;
+	  utf8::encode($row->[1]) if (utf8::is_valid_utf8($row->[1]));
+	}
     }
     return $row;
 }
