@@ -36,7 +36,7 @@ use DBI::Library qw(:all $m_dbh $m_dsn);
         qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
     ],
 );
-$DBI::Library::Database::VERSION = '0.98';
+$DBI::Library::Database::VERSION = '0.99';
 $m_nSecs                         = 10;
 
 =head1 NAME
@@ -1107,7 +1107,7 @@ regexp search in tabelle ...
 sub searchDB {
     my ($self, @p) = getSelf(@_);
     my $p_sQuery = $p[0];
-    eval("return 0 if/($p_sQuery)/;");
+    eval{return 0 if/($p_sQuery)/;};
     return "Invalid regexp : $@" if $@;
     $p_sQuery = $self->quote($p_sQuery);
     my $p_sCol = $p[1];
@@ -1166,7 +1166,7 @@ fulltextsuche in tabelle ...
 sub fulltext {
     my ($self, @p) = getSelf(@_);
     my $p_sQuery = $p[0];
-    eval("return 0 if/($p_sQuery)/;");
+    eval{return 0 if/($p_sQuery)/;};
     return "Invalid Query : <br/>" if $@;
     $p_sQuery = $self->quote($p_sQuery);
     my $p_sTable = $p[1];
