@@ -27,7 +27,7 @@ use vars
 @MySQL::Admin::GUI::EXPORT =
   qw( ContentHeader Body ChangeDb Unique openFile action applyRights maxlength);
 @ISA                        = qw( Exporter MySQL::Admin );
-$MySQL::Admin::GUI::VERSION = '0.98';
+$MySQL::Admin::GUI::VERSION = '0.99';
 $m_bMod_perl                = ($ENV{MOD_PERL}) ? 1 : 0;
 local $^W = 0;
 our @m_processlist;
@@ -135,11 +135,11 @@ sub ContentHeader {
         my $u  = param('user');
         my $p  = param('pass');
         $m_nSkipCaptch = 0;
-        eval('
-        use Authen::Captcha;
-        my $captcha = Authen::Captcha->new(data_folder   => "$m_hrSettings->{cgi}{bin}/config/",output_folder => "$m_hrSettings->{cgi}{DocumentRoot}/images");
-        $m_nSkipCaptch = $captcha->check_code(param("captcha"), param("md5"));
-        ');
+        eval{
+	  use Authen::Captcha;
+	  my $captcha = Authen::Captcha->new(data_folder   => "$m_hrSettings->{cgi}{bin}/config/",output_folder => "$m_hrSettings->{cgi}{DocumentRoot}/images");
+	  $m_nSkipCaptch = $captcha->check_code(param("captcha"), param("md5"));
+        };
         $m_nSkipCaptch = 1 if $@;
         if (defined $u && defined $p && defined $ip && $m_nSkipCaptch > 0) {
             use MD5;
@@ -280,7 +280,7 @@ sub Body {
 
 sub ChangeDb {
     my $hash = shift;
-    my $m_sTitle = $hash->{title} if (defined $hash->{title});
+    my $m_sTitle = defined $hash->{title} ? $hash->{title} : "";
     $m_dbh = $m_oDatabase->initDB(
                                   {
                                    name     => $hash->{name},
@@ -369,9 +369,9 @@ sub applyRights {
 
 sub action {
     my $hash     = shift;
-    my $title    = $hash->{title} if (defined $hash->{title});
-    my $src      = $hash->{src} if (defined $hash->{src});
-    my $location = $hash->{location} if (defined $hash->{location});
+    my $title    = defined $hash->{title} ?  $hash->{title} : "";
+    my $src      = defined $hash->{src}   ?  $hash->{src}  : "";
+    my $location = defined $hash->{location} ? $hash->{location} : "";
     if ($location !~ /^javascript:/) {
         $location = "requestURI('$location',this.id,'$title')";
     }
